@@ -192,6 +192,7 @@ class TopLevelCommand(object):
                                   (default: docker-compose.yml)
       -p, --project-name NAME     Specify an alternate project name
                                   (default: directory name)
+      -c, --context NAME          Specify a context name
       --verbose                   Show more output
       --log-level LEVEL           Set log level (DEBUG, INFO, WARNING, ERROR, CRITICAL)
       --no-ansi                   Do not print ANSI control characters
@@ -1079,7 +1080,7 @@ class TopLevelCommand(object):
                 log.error(
                     "The image for the service you're trying to recreate has been removed. "
                     "If you continue, volume data could be lost. Consider backing up your data "
-                    "before continuing.\n".format(e.explanation)
+                    "before continuing.\n"
                 )
                 res = yesno("Continue with the new image? [yN]", False)
                 if res is None or not res:
@@ -1201,7 +1202,7 @@ def image_digests_for_project(project):
 
         if e.needs_push:
             command_hint = (
-                "Use `docker-compose push {}` to push them. "
+                "Use `docker push {}` to push them. "
                 .format(" ".join(sorted(e.needs_push)))
             )
             paras += [
@@ -1212,7 +1213,7 @@ def image_digests_for_project(project):
 
         if e.needs_pull:
             command_hint = (
-                "Use `docker-compose pull {}` to pull them. "
+                "Use `docker pull {}` to pull them. "
                 .format(" ".join(sorted(e.needs_pull)))
             )
 
